@@ -1,17 +1,15 @@
-###
-# XML::SAX::Writer - SAX2 XML Writer
-# Robin Berjon <robin@knowscape.com>
-###
-
 package XML::SAX::Writer::XML;
+$XML::SAX::Writer::XML::VERSION = '0.56';
 use strict;
 use XML::NamespaceSupport   qw();
 @XML::SAX::Writer::XML::ISA = qw(XML::SAX::Writer);
 
+# ABSTRACT: XML::SAX::Writer's SAX Handler
+
+###
+# Robin Berjon <robin@knowscape.com>
+###
 
-#,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,#
-#`,`, The SAX Handler `,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,#
-#```````````````````````````````````````````````````````````````````#
 
 #-------------------------------------------------------------------#
 # start_document
@@ -100,7 +98,7 @@ sub start_element {
     # build a string from what we have, and buffer it
     my $el = '<' . $data->{Name};
     for my $k (keys %attr_hash) {
-        $el .= ' ' . $k . '=\'' . $self->escape($attr_hash{$k}) . '\'';
+        $el .= ' ' . $k . qq[=$self->{QuoteCharacter}] . $self->escape($attr_hash{$k}) . qq[$self->{QuoteCharacter}];
     }
 
     $self->{BufferElement} = $el;
@@ -443,9 +441,9 @@ sub start_entity {
     my $ent;
     if ($data->{Name} eq '[dtd]') {
         # we ignore the fact that we're dealing with an external
-        # DTD entity here, and prolly shouldn't write the DTD
+        # DTD entity here, and probably shouldn't write the DTD
         # events unless explicitly told to
-        # this will prolly change
+        # this will probably change
     }
     elsif ($data->{Name} =~ m/^%/) {
         $ent = $data->{Name} . ';';
@@ -536,11 +534,19 @@ sub _output_dtd {
 #`,`, Documentation `,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,`,#
 #```````````````````````````````````````````````````````````````````#
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-XML::SAX::Writer::XML - SAX2 XML Writer
+XML::SAX::Writer::XML - XML::SAX::Writer's SAX Handler
+
+=head1 VERSION
+
+version 0.56
 
 =head1 SYNOPSIS
 
@@ -550,13 +556,17 @@ XML::SAX::Writer::XML - SAX2 XML Writer
 
 ...
 
+=head1 NAME
+
+XML::SAX::Writer::XML - SAX2 XML Writer
+
 =head1 AUTHOR
 
 Robin Berjon, robin@knowscape.com
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2006 Robin Berjon nad Perl XML project. All rights reserved. 
+Copyright (c) 2001-2006 Robin Berjon and Perl XML project. All rights reserved. 
 This program is free software; you can redistribute it and/or modify it under 
 the same terms as Perl itself.
 
@@ -564,5 +574,25 @@ the same terms as Perl itself.
 
 XML::SAX::*
 
-=cut
+=head1 AUTHORS
 
+=over 4
+
+=item *
+
+Robin Berjon <robin@knowscape.com>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Robin Berjon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
